    processor 16f18446
    #include <xc.inc>
    config "FEXTOSC" = "OFF"	    ; enable or disable external oscillator or crystallor 
    config "RSTOSC" = "HFINT32"	    ; select internal RC 32MHz
    config "CLKOUTEN" = "ON"	    ; CLK output enable or disable
    config "CSWEN" = "ON"	    ; enable or disable NOSC & NDIV writeable
    config "FCMEN" = "OFF"	    ; suggest disable function at debug mode
    config "MCLRE" = "ON"	    ; MCLR enable or disable. When disable, can be input pin
    config "PWRTS" = "OFF"	    ; power up timer enable or disable. At design stage, suggest disable this function
    config "LPBOREN" = "OFF"	    ; low power BOR enable or disable. At design stage, suggest disable this function
    config "BOREN" = "OFF"	    ; BOR enable or disable. At design stage, suggest disable this function
    config "BORV" = "HI"	    ; BOR voltage level high or low
    config "ZCD" = "OFF"	    ; enable or disable ZCD function at power on reset
    config "PPS1WAY" = "OFF"	    ; peripheral pin select only one way or always can be repearted. At design stage, suggest enable this function 
    config "STVREN" = "OFF"	    ; stack overflow or underflow cause chip reset. I like to enable this function
    config "WDTCPS" = "WDTCPS_18"   ; WDT period select
    config "WDTE" = "OFF"	    ; WDT disable, At design stage, suggest disable this function
    config "WDTCWS" = "WDTCWS_7"    ; if WDT disable, don't care these bits
    config "WDTCCS" = "HFINTOSC"    ; WDT clock source select,if WDT disable, don't care these bits 
    config "BBSIZE" = "BB8K"	    ; boot block size select bits. If boot block disable,don't care these bits 
    config "BBEN" = "OFF"	    ; enable or disable boot block
    config "SAFEN" = "OFF"	    ; store area flash enable or disable
    config "WRTAPP" = "OFF"	    ; application block write protection
    config "WRTB" = "OFF"	    ; boot block write protection
    config "WRTC" = "OFF"	    ; configuration register write protection
    config "WRTD" = "OFF"	    ; Data EEPROM write protection
    config "WRTSAF" = "OFF"	    ; store area flash write protection
    config "LVP" = "ON"		    ; Low Voltage Programming Enable bit
    config "CP" = "OFF"		    ; UserNVM Program memory code protection bit

#define	SW3	PORTC,PORTC_RC0_POSITION
#define VAL_US  249
d_200	equ	200
time_base   equ	250	
on_count    equ	100
off_count   equ	250
iv_on	    equ	250
iv_off	    equ	100	    
	
PSECT	udata
count:	ds	1
c_200:	ds	1
on_time:	ds	1
off_time:    ds	1
    
PSECT resetVec, class=CODE,delta=2    
resetVec:
	pagesel	start 
	goto start  
	
PSECT	code

start:

; configuration set OSC = 32MHz, has to divide 8, then OSC = 4MHz
	banksel	OSCCON1
	movlw	0b01100011
	movwf	OSCCON1
; waiting OSC switch ready	
wait:	
	btfss	ORDY
	goto	wait

;set I/O pin to be digital or analog IO	
	banksel	ANSELA
	movlw	0b00000000
	movwf	ANSELA
	movwf	ANSELB
	movlw	0b00001000
	movwf	ANSELC

; enable or disable weak pull-up	
	clrf	WPUA
	clrf	WPUB
	clrf	WPUC

; enable or disable open-drain	
	clrf	ODCONA
	movlw	0b01010000	; RB6 & RB4 are I2C interface
	movwf	ODCONB
	clrf	ODCONC

; enable or disable low slew rate	
	clrf	SLRCONA
	movlw	0b01010000	; RB6 & RB4 are I2C interface
	movwf	SLRCONB
	clrf	SLRCONC

; select ST or TTL input, 1=ST input, 0=TTL input	
	movlw	0xff
	movwf	INLVLA
	movwf	INLVLB
	movwf	INLVLC
	
	banksel PORTA
	clrf	PORTA
	clrf	PORTB
	clrf	PORTC
	
	clrf	LATA
	clrf	LATB
	clrf	LATC

; select I/O pin be input or output, 1=input, 0=output	
	movlw	0b11001011
	movwf	TRISA
	movlw	0b01111111
	movwf	TRISB
	movlw	0b00011011
	movwf	TRISC

; setting Timer 0 operation mode	
	banksel T0CON0
; To Do : T0CON1 register, setting clock source MFINTOSC(500KHz), input Asynchronization bit, and prescaler rate 1:2
					;
	movwf	T0CON1			;
; To Do : T0CON0 register, disable Timer0, 8-bit mode, postscaler 1:1	
					;
	movwf	T0CON0
;To Do : move time base to Time 0 counter high byte
				;
				;
	clrf	TMR0L
	banksel	PIR0
;To Do : clear Timer 0 interrupt flag	
				;
	
repeat:   
	banksel	LATA
	bsf	LATA2   ;
	call	checkkey	;
	movf	on_time,w
	call	delay_200ms ;
	banksel	LATA
	bcf	LATA2   ;
	call	checkkey	;
	movf	off_time,w
	call	delay_200ms ;
	goto	repeat

checkkey:
	btfss	SW3
	goto	pushkey
	movlw	on_count
	movwf	on_time
	movlw	off_count
	movwf	off_time
	return
pushkey:
	movlw	iv_on
	movwf	on_time
	movlw	iv_off
	movwf	off_time
	return    
	
delay_200ms:    
	movwf	c_200
	banksel	T0CON0
; To Do : enable Timer 0 to start counting	
				;
loop_1:
	banksel	PIR0
	btfss	TMR0IF
	goto	loop_1
	bcf	TMR0IF
	banksel	c_200
	decfsz	c_200,f
	goto	loop_1
	banksel	T0CON0
	bcf	T0EN
	return

	end	resetVec



