
    processor 16f18446
    #include <xc.inc>
    config "FEXTOSC" = "OFF"	    ; enable or disable external oscillator or crystallor 
    config "RSTOSC" = "HFINT32"	    ; select internal RC 32MHz
    config "CLKOUTEN" = "ON"	    ; CLK output enable or disable
    config "CSWEN" = "ON"	    ; enable or disable NOSC & NDIV writeable
    config "FCMEN" = "OFF"	    ; suggest disable function at debug mode
    config "MCLRE" = "ON"	    ; MCLR enable or disable. When disable, can be input pin
    config "PWRTS" = "OFF"	    ; power up timer enable or disable. At design stage, suggest disable this function
    config "LPBOREN" = "OFF"	    ; low power BOR enable or disable. At design stage, suggest disable this function
    config "BOREN" = "OFF"	    ; BOR enable or disable. At design stage, suggest disable this function
    config "BORV" = "HI"	    ; BOR voltage level high or low
    config "ZCD" = "OFF"	    ; enable or disable ZCD function at power on reset
    config "PPS1WAY" = "OFF"	    ; peripheral pin select only one way or always can be repearted. At design stage, suggest enable this function 
    config "STVREN" = "OFF"	    ; stack overflow or underflow cause chip reset. I like to enable this function
    config "WDTCPS" = "WDTCPS_18"   ; WDT period select
    config "WDTE" = "OFF"	    ; WDT disable, At design stage, suggest disable this function
    config "WDTCWS" = "WDTCWS_7"    ; if WDT disable, don't care these bits
    config "WDTCCS" = "HFINTOSC"    ; WDT clock source select,if WDT disable, don't care these bits 
    config "BBSIZE" = "BB8K"	    ; boot block size select bits. If boot block disable,don't care these bits 
    config "BBEN" = "OFF"	    ; enable or disable boot block
    config "SAFEN" = "OFF"	    ; store area flash enable or disable
    config "WRTAPP" = "OFF"	    ; application block write protection
    config "WRTB" = "OFF"	    ; boot block write protection
    config "WRTC" = "OFF"	    ; configuration register write protection
    config "WRTD" = "OFF"	    ; Data EEPROM write protection
    config "WRTSAF" = "OFF"	    ; store area flash write protection
    config "LVP" = "ON"		    ; Low Voltage Programming Enable bit
    config "CP" = "OFF"		    ; UserNVM Program memory code protection bit


time_base   equ	250
d_count	    equ	7
period	    equ	249
max_duty    equ	period+1
time_acq    equ	8
ad_clk	    equ	1
	
PSECT	udata
count:	ds	1


PSECT resetVec, class=CODE,delta=2    
resetVec:
	pagesel	start 
	goto start
	
PSECT isrVec, class=CODE,delta=2
isr:
	pagesel	$
	banksel	PIR0
	btfss	TMR0IF
	retfie
	bcf	TMR0IF
	banksel	count
	decfsz	count,f
	retfie
	movlw	d_count
	movwf	count

;add trigger ADC converter in interrupt routine 	
	banksel	ADCON0
	bsf ADGO
	retfie
	
PSECT	code

start:

; configuration set OSC = 32MHz, has to divide 8, then OSC = 4MHz
	banksel	OSCCON1
	movlw	0b01100011
	movwf	OSCCON1
; waiting OSC switch ready	
wait:	
	btfss	ORDY
	goto	wait

;set I/O pin to be digital or analog IO	
	banksel	ANSELA
	clrf	ANSELA
	clrf	ANSELB
	clrf	ANSELC
	movlw	0b00001000
	movwf	ANSELC

; enable or disable weak pull-up, 0 : disable, 1 : enable	
	clrf	WPUA
	clrf	WPUB
	clrf	WPUC

; enable or disable open-drain, 0 : disable, 1 : enable	
	clrf	ODCONA
	movlw	0b01010000	; RB6 & RB4 are I2C interface
	movwf	ODCONB
	clrf	ODCONC

; enable or disable low slew rate	
	clrf	SLRCONA
	clrf	SLRCONB
	clrf	SLRCONC

; select ST or TTL input, 1=ST input, 0=TTL input	
	movlw	0xff
	movwf	INLVLA
	movwf	INLVLB
	movwf	INLVLC
	
	banksel PORTA
	clrf	PORTA
	clrf	PORTB
	clrf	PORTC
	
	clrf	LATA
	clrf	LATB
	clrf	LATC

; select I/O pin be input or output, 1=input, 0=output
	movlw	0b11001011
	movwf	TRISA
	movlw	0b01111111
	movwf	TRISB
;	movlw	0b00011001
	movlw	0b00011011
	movwf	TRISC
	
; PWM output set to RA2
	banksel	RA2PPS
	movlw	0b00001101
	movwf	RA2PPS

; setting PWM6 clock source from Timer2	
	banksel	CCPTMRS1
	movlw	0b00000100  ; set PWM6 clock source from Timer2
	movwf	CCPTMRS1

;Setting PWM6 working register
	banksel	PWM6DCL
	clrf	PWM6DCL	    ; clear PWM6 output low duty register
	clrf	PWM6DCH	    ; clear PWM6 output high duty register
	movlw	0x80
	movwf	PWM6CON	    ; enable PWM6 output, output polarity as normal
	
; setting Timer 2 working register
	banksel	T2TMR
	clrf	T2TMR	    ; clear Timer2 counter register
	movlw	period
	movwf	T2PR	    ; setting PWM6 period
	clrf	T2HLT	    ; setting Timer 2 working mode
	movlw	0b00000001  ; Fosc/4 is Timer 2 clock source
	movwf	T2CLKCON    ;
	movlw	0b00001000  ;
	movwf	T2RST
	movlw	0b10000000  ; enable Timer 2, Prescale & Postscale 1:1
	movwf	T2CON
	
; setting ADC working register
	banksel	ADPCH
	movlw	0b00010011  ; select RC3 as analog input
	movwf	ADPCH
	clrf	ADCNT	    ; clear repeat counter
	
	banksel	ADACQL
	movlw	time_acq
	movwf	ADACQL	    ; setting acquisition time
	clrf	ADACQH
	clrf	ADCAP	    ; setting additional sample capacitor
	clrf	ADPREH	    ; clear precharge time control register
	clrf	ADPREL
	clrf	ADCON0	    ; disable continue mode, clock : Fosc, left-justified
	clrf	ADCON1
	clrf	ADCON2
	movlw	0x70
	movwf	ADCON3
	clrf	ADREF	    ; negation ref : Vss, Positive ref : Vdd
	movlw	0b00011011
	movwf	ADACT	    ; disable auto-conversion trigger source
	movlw	ad_clk
	movwf	ADCLK	    ; setting ADC clock frequence, 1Mhz, request Tad= 0.5 ~ 9us
	clrf	ADCPCON0
	bsf	ADON
	
; setting Timer 0 operation mode	
	banksel T0CON0
	movlw	0b10100001
	movwf	T0CON1
	movlw	0b00000000
	movwf	T0CON0
	movlw	time_base
	movwf	TMR0H
	clrf	TMR0L
	banksel	PIR0
	bcf	TMR0IF	    ; clear timer 0 interrupt flag
	
; setting delay counter		
	banksel	count
	movlw	d_count
	movwf	count
; enable Timer 0 interrupt	
	banksel	PIE0
	bsf	TMR0IE
; enable Timer 0	
	banksel	T0CON0
	bsf	T0EN
; enable global interrupt	
	banksel	INTCON
	bsf	GIE

; in main routine, check conversion complete	
repeat:
	banksel	ADCON0
	btfss	ADGO
	goto	repeat
repeat1:	
	btfsc	ADGO
	goto	repeat1
	banksel	ADRESH
	movf	ADRESH,w
	banksel	PWM6DCH
	movwf	PWM6DCH
	goto	repeat

	end	resetVec

